@@ -16,7 +16,7 @@
 export EXE=libE_calling_script.py
 export NUM_WORKERS=4
 
-mpirun -np $(($NUM_WORKERS+1)) python $EXE
+mpirun -np $(($NUM_WORKERS+1)) -ppn $(($NUM_WORKERS+1)) python $EXE
 
 # To use local mode instead of mpi4py (with parse_args())
 # python $EXE --comms local --nworkers $NUM_WORKERS
